==> haskell-tasty-hedgehog-1.4.0.1-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hedgehog
version:              1.4.0.1
visibility:           public
id:                   tasty-hedgehog-1.4.0.1-JqZmDrtz0HVI3aWa2d9PwR
key:                  tasty-hedgehog-1.4.0.1-JqZmDrtz0HVI3aWa2d9PwR
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  8e8df1d43170e7fdaa98f5eef7f61281
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hedgehog-1.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hedgehog-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.1-JqZmDrtz0HVI3aWa2d9PwR
depends:
    base-4.16.4.0 hedgehog-1.2-6PcYeqnRpof27D7X8ClW1m
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-45V6IUrFvI6FX8Qf0XPHba

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-1.4.0.1-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hedgehog
version:              1.4.0.1
visibility:           public
id:                   tasty-hedgehog-1.4.0.1-FPl4LTHlUuND08bDEPsEO4
key:                  tasty-hedgehog-1.4.0.1-FPl4LTHlUuND08bDEPsEO4
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  85140d837514999c3d96861ab72aba22
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hedgehog-1.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hedgehog-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.1-FPl4LTHlUuND08bDEPsEO4
depends:
    base-4.16.4.0 hedgehog-1.2-45sXUMtiCZS9ksRmbj0vBk
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
